---
template: mainpanel
source_form: markdown
name: Licensing
title: Licensing - Apache 2
updated: June 2015
---
## Open Source, Apache 2 License

Pyxie is &copy; Copyright 2016, Michael Sparks

* Note, this was written from scratch, entire on my own time, using my own
  resources and hosted on a server I pay for.

It is released as open source, under the Apache 2 License.

The short summary of this is that you can:

* Use this for any purpose
* Modify, and distribute the code
* Contribute back :-)
* In exchange you must keep copyright notices intact, include licenses, state changes etc.

Where this summary conflicts with the license text below, the license text wins.

Note: You need explicit permission to *incorporate* this into a GPL v2 project.
Usage by a GPLv2 project though is fine :-)
